neuron_morphology
=================

**[WIP] This codebase is a work in progress!** We plan to release the first version in the near future. In the meantime, we can't rule out bugs and API instabilities.

A package for working with single-neuron morphological reconstruction data, such as those in the [Allen Cell Types Database](https://celltypes.brain-map.org/). Provides tools for processing, visualizing, and analyzing such reconstructions.

For usage and installation instructions, see the [documentation](neuron_morphology.rtfd.io).

Contributing
------------
We welcome contributions! Please see our [contribution guide](CONTRIBUTING.md) for more information. Thank you!

Level of Support
----------------
We are planning on occasional updating this tool with no fixed schedule. Community involvement is encouraged through both issues and pull requests.